pylivy
======

.. image:: https://travis-ci.org/acroz/pylivy.svg?branch=master
    :target: https://travis-ci.org/acroz/pylivy

.. image:: https://badge.fury.io/py/livy.svg
    :target: https://pypi.org/project/livy/

.. image:: https://img.shields.io/pypi/pyversions/livy.svg
    :target: https://pypi.org/project/livy/

`Livy <https://livy.incubator.apache.org/>`_ is an open source REST interface
for interacting with `Spark <http://spark.apache.org/>`_. ``pylivy`` is a
Python client for Livy, enabling easy remote code execution on a Spark cluster.

Installation
------------

.. code:: bash

    $ pip install -U livy

Note that ``pylivy`` requires Python 3.6 or later.

Documentation
-------------

Documentation for ``pylivy`` is available at https://pylivy.readthedocs.io/.

Contributing
------------

Contributions to extend or improve ``pylivy`` are very welcome! Have a look at
`the relevant docs page
<https://pylivy.readthedocs.io/en/latest/contributing.html>`_ for more
information.
